pub fn add_tx_info_to_tapes(
tx: &Transaction<Pruned>,
pruned_blob_idx: u64,
prunable_blob_idx: u64,
pruned_size: usize,
prunable_size: usize,
height: &BlockHeight,
numb_rct_outputs: &mut u64,
append_tx: &mut TapesAppendTransaction<'_>,
db: &BlockchainDatabase,
) -> DbResult<TxId>Expand description
Adds the tx info and related data to the tapes, this does not add the tx blob to the tapes.